## 1.26.4 (2022-01-11)

urllib3: add "__version__" (#6890)

Co-authored-by: Shantanu <12621235+hauntsaninja@users.noreply.github.com>

## 1.26.3 (2022-01-10)

Fix urllib3.util.Retry.sleep type (#6883)

## 1.26.2 (2022-01-09)

Annotate urllib3.exceptions (#6865)

Annotate urllib3.response (#6871)

## 1.26.1 (2022-01-08)

Use types-urllib3 for requests (#6859)

Add urllib3 stubs (#6858)

